#!/bin/bash
#
# This script polls gnunet-stats repeatedly to create statistics plots. 
# All plots are written to $STATDIR as separate .png files.
#
# WARNING: upon startup, all files in $STATDIR are deleted.
#
# Requires: gnuplot
#

SLEEP=120
GNUNET=$HOME/.gnunet
STATDIR=$GNUNET/stats

##########################################################################

mkdir -p $STATDIR
rm -f $STATDIR/*

STARTTIME=`date +%s`
STARTSTRING=`date`

while true; do
	NOW=`date +%s`
	RELAT=$[$NOW-$STARTTIME]
	gnunet-stats | grep tcp -B 666 | grep \# | while read KEY DUMMY REC DUMMY SEND; do
		
		# Collect stats of previous round
		if [ -e $STATDIR/$KEY.rec ] && [ -e $STATDIR/$KEY.send ]; then
			PREVREC=`tail --lines=1 $STATDIR/$KEY.rec | sed -e "s/.* //g"`
			PREVSEND=`tail --lines=1 $STATDIR/$KEY.send | sed -e "s/.* //g"`
		else
			PREVREC=$REC
			PREVSEND=$SEND
		fi

		# Write new stats
		echo $RELAT $REC >>$STATDIR/$KEY.rec
		echo $RELAT $SEND >>$STATDIR/$KEY.send
		echo $RELAT $PREVREC $REC >>$STATDIR/$KEY.rec.diff
		echo $RELAT $PREVSEND $SEND >>$STATDIR/$KEY.send.diff
		
		# Plot incremental
		echo "set terminal png color;set output '$STATDIR/$KEY.png';set title '$KEY (incr) - x=0 at $STARTSTRING';plot '$STATDIR/$KEY.rec' title 'receive' with lines,'$STATDIR/$KEY.send' title 'send' with lines;" | nice gnuplot
		
		# Plot diff
		echo "set terminal png color;set output '$STATDIR/$KEY.diff.png';set title '$KEY (diff) - x=0 at $STARTSTRING';plot '$STATDIR/$KEY.rec.diff' thru \$3-\$2 title 'receive' with lines,'$STATDIR/$KEY.send.diff' thru \$3-\$2 title 'send' with lines;" | nice gnuplot
	
	done
	sleep $SLEEP
done

