/*
     This file is part of GNUnet
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * Wrapper around malloc/free.
 * @file include/util/xmalloc.h
 * @author Krista Bennett
 **/

#ifndef XMALLOC_H
#define XMALLOC_H

#include "config.h"

#define DEBUG_MALLOC 0

/**
 * Allocate memory. Checks the return value, aborts if no more
 * memory is available.
 **/
void * xmalloc(int size, char * site);

/**
 * Free memory. Merely a wrapper for the case that we
 * want to keep track of allocations.
 **/
void xfree(void * ptr, char * site);

/**
 * Free if not NULL.
 **/
inline void freeNonNull(void * ptr,
			char * site);

#endif
/* end of xmalloc.h */
